Installation
============

Installing the SDK
------------------

You can install the Trustwise SDK and its dependencies using pip:

.. code-block:: bash

    pip install trustwise

Requirements
------------

- Python 3.11 or higher